#!/bin/bash
# Script Name:  proxmox-lxc-size-changer.v1.sh
# Beschreibung: Ändert die Größe des LXC Containers auf die gewünschte Gesamtgröße der Disk des Containers
#               Dies gilt primär erstmal nur für die Disk mit der ID 0
# Aufruf:       bash ./proxmox-lxc-size-changer.v1.sh
# Autor:        Patrick Asmus
# Web:          https://www.media-techport.de
# Git-Reposit.: https://git.media-techport.de/scriptos/proxmox-lxc-size-changer
# Version:      1.0
# Datum:        16.07.2023
# Modifikation: Ersterstellung
#####################################################

# Variablen
lxcPath="appdata2"
fullLxcPath="/volumes/${lxcPath}"
containerID="9100"
diskFilename="vm-${containerID}-disk-0.raw"
newSize="12G"
storage="nas02"

# Container stoppen
pct stop $containerID

# Backup erstellen
vzdump $containerID --remove 0 --mode stop --notes-template 'Backup vor Größenänderung durch Script' --storage $storage

# Dateisystemprüfung
e2fsck -fy "${fullLxcPath}/images/${containerID}/${diskFilename}"

# Größe des LXC anpassen
resize2fs "${fullLxcPath}/images/${containerID}/${diskFilename}" $newSize

# Konfiguration anpassen
configFile="/etc/pve/lxc/${containerID}.conf"
sed -i "s|rootfs: ${lxcPath}:${containerID}/${diskFilename},size=.*|rootfs: ${lxcPath}:${containerID}/${diskFilename},size=${newSize}|" $configFile

# Container starten
pct start $containerID